package de.fraunhofer.iem.kpiCalculator.adapter.cve

import de.fraunhofer.iem.kpiCalculator.adapter.KpiAdapter
import de.fraunhofer.iem.kpiCalculator.model.adapter.VulnerabilityDto
import de.fraunhofer.iem.kpiCalculator.model.kpi.KpiKind
import de.fraunhofer.iem.kpiCalculator.model.kpi.RawValueKpiCreateDto

object CveAdapter : KpiAdapter<VulnerabilityDto> {
    override val kpiKind: KpiKind
        get() = KpiKind.VULNERABILITY_SCORE

    override fun transformDataToKpi(data: List<VulnerabilityDto>): List<RawValueKpiCreateDto> {
        return data
            .filter(CveAdapter::filterData)
            .map {
                RawValueKpiCreateDto(
                    kind = kpiKind,
                    score = (it.severity * 10).toInt()
                )
            }
    }

    private fun filterData(data: VulnerabilityDto): Boolean {
        return (
            data.severity in 0.0..10.0 &&
                data.packageName.isNotBlank() &&
                data.cveIdentifier.isNotBlank()
            )
    }
}
